@@ -186,8 +186,20 @@ class LibraryExperiment(object):
             filtered_count_mat.to_csv("filtered_count_matrix.csv", index=False, float_format="%.0f")
             
             self.count_mat = filtered_count_mat
-
-
+            
+        # normalized count matrix to counts per million
+        normalized_count_mat = self.count_mat
+        counts = normalized_count_mat[self.pools].values.astype(float)
+        counts = (counts/np.sum(counts, axis=0))*1e6
+        normalized_count_mat[self.pools] = counts
+        
+        self.normalized_count_mat = normalized_count_mat
+        
+        # apply count filters to reduce noise
+        counts = global_filter_counts(counts, thr=self.global_filter_thr)
+        counts = local_filter_counts(counts, thr=self.filter_thr)
+        normalized_count_mat[self.pools] = counts
+        self.normalized_count_mat = normalized_count_mat
         
     def deconvolve(self, barcode_only=False):
         """
